@@ -32,7 +32,6 @@ class Address(db.Base):  # type: ignore
     address_performance_ranks = orm.relationship(
         "AddressPerformanceRank", back_populates="address"
     )
-    users = orm.relationship("User", secondary=users_to_addresses, backref="addresses")
 
     def __repr__(self) -> str:
         return f"address: {self.address}, blockchain_type: {self.blockchain_type}"
@@ -105,7 +104,7 @@ class User(SQLAlchemyBaseUserTableUUID, db.Base):
         DateTime(timezone=True), server_default=func.now(), onupdate=func.now()
     )
     addresses = orm.relationship("Address", secondary=users_to_addresses,
-                                 backref="users")
+                                 back_populates="users")
 
     def __repr__(self):
         return f"User(id={self.id!r}, name={self.email!r})"
